# -*- coding: utf-8 -*-

'''
@name: configs
@author: Memory&Xinxin
@date: 2019/11/22
@document: 配置游戏中的一些全局设置
'''

import os
import pygame

'''游戏参数设置'''
MAX_TIME = 20               # 多久不操作会被计一次超时
MAX_TIMEOUT = 3             # 几次超时会被判输
MAX_NOEAT = 30              # 几步不吃子或者翻棋会被判和棋
MIN_GIVEUP = 20             # 几步以后才可以认输
WIN_CREDIT = 20             # 赢了棋加的积分

'''窗口设置'''
WINDOW_TITILE = '皇家战棋 For Xinxin By Memory'  # 窗口标题
WINDOW_SIZE = (1000, 650)                       # 游戏窗口大小

'''位置设置。除非你很清楚你在做什么，不然不要改这些'''
ROW = 6                                         # 棋盘格的数量是 6*6

CHESSBOARD_POS = (200, -50)                     # 棋盘偏移的位置
CHESSBOARD = [                                  # 定义棋盘的二位数组，每个元素是棋盘纵横线的一个交点
    [[79, 209], [153, 209], [226, 209], [300, 209], [373, 210], [446, 210], [520, 210]],
    [[71, 260], [147, 260], [223, 260], [300, 260], [376, 260], [452, 260], [528, 260]],
    [[61, 314], [141, 314], [220, 314], [300, 314], [379, 314], [458, 314], [538, 314]],
    [[51, 373], [134, 373], [217, 373], [300, 373], [382, 373], [465, 373], [548, 373]],
    [[40, 437], [127, 437], [213, 437], [300, 437], [386, 437], [472, 437], [559, 437]],
    [[28, 507], [118, 507], [209, 507], [300, 507], [390, 507], [481, 507], [571, 507]],
    [[15, 585], [110, 585], [205, 585], [300, 585], [395, 585], [490, 585], [585, 585]]
]
CHESS_SIZE = [124, 132, 140, 148, 156, 164]     # CHESS_SIZE[i]表示从上往下数第 i 层上的棋子尺寸
CHESS_POS = [                                   # CHESS_POS[i][j]表示当棋子处于(i ,j)位置时，棋子要blit的位置
    [[52, 124], [127, 124], [200, 124], [275, 124], [348, 124], [424, 124]],
    [[41, 169], [118, 169], [195, 169], [273, 169], [349, 169], [426, 169]],
    [[28, 218], [109, 218], [189, 218], [270, 218], [350, 218], [430, 218]],
    [[15, 275], [100, 275], [184, 275], [267, 275], [351, 275], [436, 275]],
    [[0, 336], [90, 336], [177, 336], [265, 336], [353, 336], [441, 336]],
    [[-15, 404], [77, 404], [170, 404], [262, 404], [355, 404], [448, 404]]
]
BODER = [[69, 199], [0, 600], [600, 600], [530, 200]]   # 定义棋盘边框的四个点
TIME_POS = [(45, 300), (805, 300)]                      # 剩余时间所在的位置


def move_pos(pos_list):
    '''
    给所有位置加上一个偏移。
    '''
    if len(pos_list) == 2:
        pos_list[0] += CHESSBOARD_POS[0]
        pos_list[1] += CHESSBOARD_POS[1]
        return
    for pl in pos_list:
        move_pos(pl)


move_pos(CHESSBOARD)
move_pos(CHESS_POS)
move_pos(BODER)

DIRECTION = {pygame.K_UP: (0, -1), pygame.K_LEFT: (-1, 0), pygame.K_RIGHT: (1, 0), pygame.K_DOWN: (0, 1), '0': (0, 0)}


'''颜色设置'''
COLOR = {
        'boder': '0xFFD04B',        # 棋盘边框的颜色
        'board_1': '0xAA8FC3',      # 棋盘格颜色
        'board_2': '0xFFFFFF',      # 棋盘格颜色
        'hover': '0x22EE22',        # 鼠标悬停时棋盘格的颜色
        'select': '0xFF9900',       # 棋子被选中时棋盘格的颜色
        'next': '0xB0E2FF',         # 被选中的棋子下一步可走的棋盘格颜色
        'last_step': '0x9AFF9A',    # 上一步翻开或者移动的棋子位置
        'time_text': '0xCD4F39'     # 时间字体的颜色
        }
for k, v in COLOR.items():          # 转换成pyagme里能用的格式
    COLOR[k] = pygame.color.Color(v)

'''路径设置'''
ROOT_PATH = os.path.dirname(os.path.abspath(__file__))      # 获取文件所在目录的绝对路径
IMG_PATH = os.path.join(ROOT_PATH, 'src', 'image')          # 图像的路径
ALL_IMG = {}                                                # 存储所有图像名与路径的键值对
imgs = os.listdir(IMG_PATH)
for img in imgs:
    img_name = img.split('.')[0]
    file = os.path.join(IMG_PATH, img)
    ALL_IMG[img_name] = file

SERVER_LOG_PATH = os.path.join(ROOT_PATH, 'log', 'server')     # 服务器的日志文件路径
CLIENT_LOG_PATH = os.path.join(ROOT_PATH, 'log', 'client')     # 客户端的日志文件路径

LOGIN_LOG = os.path.join(SERVER_LOG_PATH, 'log_qq.txt')

DATABASE_PATH = os.path.join(ROOT_PATH, 'database')
USERDB = os.path.join(DATABASE_PATH, 'users.db')               # 数据库的路径

'''IP 设置，联网对战的服务器'''
HOST = '39.106.67.160'              # 服务器地址
PORT = 1122                         # 端口
LOCAL_HOST = '127.0.0.1'            # 本地服务器地址
LOCAL_PORT = 1122                   # 本地端口


'''随机用户设置'''
# 随机的姓
XING = '赵钱孙李周吴郑王冯陈褚卫蒋沈韩杨朱秦尤许何吕施张孔曹严华金魏陶姜戚谢邹喻柏水窦章云苏潘葛' \
       '奚范彭郎鲁韦昌马苗凤花方俞任袁柳酆鲍史唐费廉岑薛雷贺倪汤滕殷罗毕郝邬安常乐于时傅皮卞齐康' \
       '伍余元卜顾孟平黄和穆萧尹姚邵湛汪祁毛禹狄米贝明臧计伏成戴谈宋茅庞熊纪舒屈项祝董梁杜阮蓝闵' \
       '席季麻强贾路娄危江童颜郭梅盛林刁钟徐邱骆高夏蔡田樊胡凌霍虞万支柯昝管卢莫经房裘缪干解应宗' \
       '丁宣贲邓郁单杭洪包诸左石崔吉钮龚程嵇邢滑裴陆荣翁荀羊於惠甄曲家封芮羿储靳汲邴糜松井段富巫' \
       '乌焦巴弓牧隗山谷车侯宓蓬全郗班仰秋仲伊宫宁仇栾暴甘钭厉戎祖武符刘景詹束龙叶幸司韶郜黎蓟薄' \
       '印宿白怀蒲邰从鄂索咸籍赖卓蔺屠蒙池乔阴鬱胥能苍双闻莘党翟谭贡劳逄姬申扶堵冉宰郦雍卻璩桑桂' \
       '濮牛寿通边扈燕冀郏浦尚农温别庄晏柴瞿阎充慕连茹习宦艾鱼容向古易慎戈廖庾终暨居衡步都耿满弘' \
       '匡国文寇广禄阙东欧殳沃利蔚越夔隆师巩厍聂晁勾敖融冷訾辛阚那简饶空曾毋沙乜养鞠须丰巢关蒯相' \
       '查后荆红游竺权逯盖益桓公万俟司马上官欧阳夏侯诸葛闻人东方赫连皇甫尉迟公羊澹台公冶宗政濮阳' \
       '淳于单于太叔申屠公孙仲孙轩辕令狐钟离宇文长孙慕容鲜于闾丘司徒司空丌官司寇仉督子车颛孙端木' \
       '巫马公西漆雕乐正壤驷公良拓跋夹谷宰父谷梁晋楚闫法汝鄢涂钦段干百里东郭南门呼延归海羊舌微生' \
       '岳帅缑亢况郈有琴梁丘左丘东门西门商牟佘佴伯赏南宫墨哈谯笪年爱阳佟第五言福'
# 随机的名
MING = '伟刚勇毅俊峰强军平保东文辉力明永健世广志义兴良海山仁波宁贵福生龙元全国胜学祥才发武新利清' \
       '飞彬富顺信子杰涛昌成康星光天达安岩中茂进林有坚和彪博诚先敬震振壮会思群豪心邦承乐绍功松善' \
       '厚庆磊民友裕河哲江超浩亮政谦亨奇固之轮翰朗伯宏言若鸣朋斌梁栋维启克伦翔旭鹏泽晨辰士以建家' \
       '致树炎德行时泰盛秀娟英华慧巧美娜静淑惠珠翠雅芝玉萍红娥玲芬芳燕彩春菊兰凤洁梅琳素云莲真环' \
       '雪荣爱妹霞香月莺媛艳瑞凡佳嘉琼勤珍贞莉桂娣叶璧璐娅琦晶妍茜秋珊莎锦黛青倩婷姣婉娴瑾颖露瑶' \
       '怡婵雁蓓纨仪荷丹蓉眉君琴蕊薇菁梦岚苑筠柔竹霭凝晓欢霄枫芸菲寒欣滢伊亚宜可姬舒影荔枝思丽秀' \
       '飘育馥琦晶妍茜秋珊莎锦黛青倩婷宁蓓纨苑婕馨瑗琰韵融园艺咏卿聪澜纯毓悦昭冰爽琬茗羽希'
# 战棋中积分和称号
TITLE = {'平民': (0, 40), '小农场主': (40, 100), '大农场主': (100, 200), '贵族': (200, 360),
         '小城主': (360, 760), '大城主': (760, 1400), '男爵': (1400, 2600), '子爵': (2600, 4400),
         '伯爵': (4400, 7600), '侯爵': (7600, 15000), '公爵': (15000, 33000), '国王': (33000, 65000),
         '教皇': (65000, 999999)}
